@@ -239,7 +239,7 @@ class MetaCAT(object):
                               nclasses=nclasses)
             path = self.save_dir + "lstm.dat"
 
-        self.model.load_state_dict(torch.load(path), map_location=self.device)
+        self.model.load_state_dict(torch.load(path, map_location=self.device))
 
 
     def load(self, model='lstm', tokenizer_name='bbpe'):
