@@ -95,9 +95,9 @@ def are_anns_same(ann, ann2, meta_names=[], require_double_inner=True):
             if meta_ann is not None and meta_ann2 is not None:
                 if meta_ann['value'] != meta_ann2['value']:
                     return False
-            elif (meta_ann is None) != (meta_ann2 is None):
-                if require_double_inner:
-                    return False
+            elif require_double_inner:
+                # Remove all annotations that do not have the required meta_anns
+                return False
     else:
         return False
 
@@ -109,23 +109,34 @@ def get_same_anns(document, document2, require_double_inner=True, ann_stats=[],
     new_document = copy.deepcopy(document)
     new_document['annotations'] = []
 
+    if not ann_stats:
+        ann_stats.append([])
+        ann_stats.append([])
+
     for ann in document['annotations']:
         # Take only validated anns
         if ann['validated']:
             ann2 = get_ann_from_doc(document2, ann['start'], ann['end'])
 
             if ann2 is not None:
+                pair = [0, 0]
+                if ann['correct']:
+                    pair[0] = 1
+                if ann2['correct']:
+                    pair[1] = 1
+                ann_stats[1].append(pair)
+
                 if not are_anns_same(ann, ann2, meta_names):
-                    ann_stats.append((1, 0))
+                    ann_stats[0].append((1, 0))
                     are_same = False
                 else:
-                    ann_stats.append((1, 1))
+                    ann_stats[0].append((1, 1))
                     new_document['annotations'].append(ann)
             elif not require_double_inner:
-                ann_stats.append((1, 1))
+                ann_stats[0].append((1, 1))
                 new_document['annotations'].append(ann)
             else:
-                ann_stats.append((1, 0))
+                ann_stats[0].append((1, 0))
                 are_same = False
 
     # Check the reverse also, but only ann2 if not in first doc
@@ -134,11 +145,11 @@ def get_same_anns(document, document2, require_double_inner=True, ann_stats=[],
 
         if ann is None:
             if not require_double_inner:
-                ann_stats.append((1, 1))
+                ann_stats[0].append((1, 1))
                 # Also append this annotation to the document, because it is missing from it
                 new_document['annotations'].append(ann2)
             else:
-                ann_stats.append((0, 1))
+                ann_stats[0].append((0, 1))
                 are_same = False
 
     return new_document
@@ -147,15 +158,17 @@ def get_same_anns(document, document2, require_double_inner=True, ann_stats=[],
 
 def print_consolid_stats(ann_stats=[]):
     if ann_stats:
-        ann_stats = np.array(ann_stats)
-        ck = cohen_kappa_score(ann_stats[:, 0], ann_stats[:, 1])
+        _ann_stats = np.array(ann_stats[1])
+        ck = cohen_kappa_score(_ann_stats[:, 0], _ann_stats[:, 1])
+
+        _ann_stats = np.array(ann_stats[0])
         t = 0
-        for i in range(len(ann_stats)):
-            if ann_stats[i, 0] == ann_stats[i, 1]:
+        for i in range(len(_ann_stats)):
+            if _ann_stats[i, 0] == _ann_stats[i, 1]:
                 t += 1
-        agr = t / len(ann_stats)
+        agr = t / len(_ann_stats)
         print("Kappa: {:.4f}; Agreement: {:.4f}".format(ck, agr))
-        print("InAgreement vs Total: {} / {}".format(t, len(ann_stats)))
+        print("InAgreement vs Total: {} / {}".format(t, len(_ann_stats)))
 
 
 def check_differences(data_path, cat, cntx_size=30, min_acc=0.2, ignore_already_done=False, only_start=False, only_saved=False):
@@ -373,7 +386,11 @@ def consolidate_double_annotations(data_path, out_path, require_double=True, req
                     new_project['documents'] = new_documents
 
             if new_project is not None:
-                ann_stats.extend(ann_stats_project)
+                if not ann_stats:
+                    for one in ann_stats_project:
+                        ann_stats.append([])
+                for irow, one in enumerate(ann_stats_project):
+                    ann_stats[irow].extend(one)
                 out_data['projects'].append(new_project)
 
             if ann_stats_project:
